@import "breakpoint";
@import "singularitygs";

$basic-settings: false !default;

$add-grid: 3, 5 at 500px, 1 3 5 7 at 700px !default;
$add-gutter: .25, 10px at 500px, 1em at 700px !default;
$add-gutter-style: 'split', 'opposite' at 700px !default;

$bkpts: 499px, 500px, 699px, 700px !default;

$grid-override: 2 4 6 !default;
$gutter-override: .4 !default;
$gutter-style-override: 'split fixed' !default;

@mixin show-settings {
  _default-settings: "#{inspect($Singularity-Settings)}";
  _user-settings: "#{inspect($singularity)}";
}

@if $basic-settings {
  @each $grid in $add-grid {
    @include add-grid($grid);
  }

  @each $gutter in $add-gutter {
    @include add-gutter($gutter);
  }

  @each $gutter-style in $add-gutter-style {
    @include add-gutter-style($gutter-style);
  }

  .settings {
    @include show-settings;
  }
}