.settings {
  _default-settings: '("grids": (-1px: 12), "gutters": (-1px: 0.25), "gutter styles": (-1px: "opposite"), "output": "isolation", "direction": "ltr", "mobile first": true, "include border box": false, "include clearfix": false, "background grid color": chocolate, "asymmetric output": "isolation", "calc include min-width": true, "debug": false)';
  _user-settings: '("grids": (-1px: 3, 500px: 5, 700px: 1 3 5), "gutters": (-1px: 0.25, 500px: 0.35, 700px: 0.55), "gutter styles": (-1px: "split", 500px: "fixed", 700px: "opposite fixed"))';
  _grid-override: 2 4 6;
  _gutter-override: 0.4;
  _gutter-style-override: "split fixed"; }

.find-grid {
  _map: 'false';
  _find: "3";
  _map: 'true';
  _find: "3"; }
  @media (min-width: 499px) {
    .find-grid {
      _map: 'false';
      _find-layout: "2 4 6"; } }
  @media (min-width: 500px) {
    .find-grid {
      _map: 'false';
      _find-layout: "2 4 6"; } }
  @media (min-width: 699px) {
    .find-grid {
      _map: 'false';
      _find-layout: "2 4 6"; } }
  @media (min-width: 700px) {
    .find-grid {
      _map: 'false';
      _find-layout: "2 4 6"; } }
  @media (min-width: 499px) {
    .find-grid {
      _map: 'true';
      _find-layout: "2 4 6"; } }
  @media (min-width: 500px) {
    .find-grid {
      _map: 'true';
      _find-layout: "2 4 6"; } }
  @media (min-width: 699px) {
    .find-grid {
      _map: 'true';
      _find-layout: "2 4 6"; } }
  @media (min-width: 700px) {
    .find-grid {
      _map: 'true';
      _find-layout: "2 4 6"; } }

.find-gutter {
  _find: "0.25"; }
  @media (min-width: 499px) {
    .find-gutter {
      _find-layout: "0.4"; } }
  @media (min-width: 500px) {
    .find-gutter {
      _find-layout: "0.4"; } }
  @media (min-width: 699px) {
    .find-gutter {
      _find-layout: "0.4"; } }
  @media (min-width: 700px) {
    .find-gutter {
      _find-layout: "0.4"; } }

.find-gutter-style {
  _find: "split"; }
  @media (min-width: 499px) {
    .find-gutter-style {
      _find-layout: "split fixed"; } }
  @media (min-width: 500px) {
    .find-gutter-style {
      _find-layout: "split fixed"; } }
  @media (min-width: 699px) {
    .find-gutter-style {
      _find-layout: "split fixed"; } }
  @media (min-width: 700px) {
    .find-gutter-style {
      _find-layout: "split fixed"; } }
