.add-gutter-basic {
  _default-settings: '("grids": (-1px: 12), "gutters": (-1px: 0.25), "gutter styles": (-1px: "opposite"), "output": "isolation", "direction": "ltr", "mobile first": true, "include border box": false, "include clearfix": false, "background grid color": chocolate, "asymmetric output": "isolation", "calc include min-width": true, "debug": false)';
  _user-settings: "()";
  _gutter: "@include add-gutter(0.25)";
  _gutter: "@include add-gutter(0.35 at 500px)";
  _gutter: "@include add-gutter(0.55 at 700px)";
  _default-settings: '("grids": (-1px: 12), "gutters": (-1px: 0.25), "gutter styles": (-1px: "opposite"), "output": "isolation", "direction": "ltr", "mobile first": true, "include border box": false, "include clearfix": false, "background grid color": chocolate, "asymmetric output": "isolation", "calc include min-width": true, "debug": false)';
  _user-settings: '("gutters": (-1px: 0.25, 500px: 0.35, 700px: 0.55))'; }

.add-gutter-breakpoint {
  _default-settings: '("grids": (-1px: 12), "gutters": (-1px: 0.25), "gutter styles": (-1px: "opposite"), "output": "isolation", "direction": "ltr", "mobile first": true, "include border box": false, "include clearfix": false, "background grid color": chocolate, "asymmetric output": "isolation", "calc include min-width": true, "debug": false)';
  _user-settings: "()";
  _gutter: "@include add-gutter(0.25)";
  _gutter: "@include add-gutter(0.35 at 500px min-resolution 1.5dppx)";
  _gutter: "@include add-gutter(0.55 at 700px, no-query .no-mq)";
  _default-settings: '("grids": (-1px: 12), "gutters": (-1px: 0.25), "gutter styles": (-1px: "opposite"), "output": "isolation", "direction": "ltr", "mobile first": true, "include border box": false, "include clearfix": false, "background grid color": chocolate, "asymmetric output": "isolation", "calc include min-width": true, "debug": false)';
  _user-settings: '("gutters": (-1px: 0.25, 500px: 0.35, 700px: 0.55))'; }
