//////////////////////////////
// Clearfix Mixin
//////////////////////////////
$clearfix-extend: false !default;

@mixin clearfix($extend: $clearfix-extend) {
  @if $extend {
    @extend %singularity-clearfix;
  }
  @else {
    &:after {
      content: "";
      display: table;
      clear: both;
    }
  }
}

%singularity-clearfix {
  @include clearfix(false);
}