@function grid-span($span, $location, $grid: false, $gutter: false, $gutter-style: false) {
  @return column-span($span, $location, $grid, $gutter, $gutter-style) + gutter-span($gutter, $grid, $gutter-style);
}