@import "../shared";

$add-grid: 3, 5 at 500px, 1 3 5 at 700px;
$add-gutter: .25, .35 at 450px, 1em at 650px;
$add-gutter-style: 'split', 'fixed' at 400px, 'opposite fixed' at 600px;

@include sgs-change('debug', true);

@each $grid in $add-grid {
  @include add-grid($grid);
}

@each $gutter in $add-gutter {
  @include add-gutter($gutter);
}

@each $gutter-style in $add-gutter-style {
  @include add-gutter-style($gutter-style);
}

.settings {
  @include show-settings;
}

.background {
  @include background-grid;
}