@import "../shared";

.setting-get {
  @include show-settings;
  _test: "sgs-get('output')";
  _result: sgs-get('output');
}

.setting-set {
  @include show-settings;
  _default: sgs-get('direction');
  _test: "@include sgs-change('direction', 'rtl')";
  @include sgs-change('direction', 'rtl');
  _new: sgs-get('direction');
  @include show-settings;
}

.setting-has {
  @include show-settings;
  _test: "sgs-has('output')";
  _result: sgs-has('output');
  _test: "sgs-has('direction')";
  _result: sgs-has('direction');
}

.setting-reset {
  @include show-settings;
  _test: "@include sgs-reset('direction')";
  @include sgs-reset('direction');
  _exists: sgs-has('direction');
  @include show-settings;

  &--multiple {
    @include show-settings;

    _test: "@include add-grid('2 4 6')";
    @include add-grid('2 4 6');
    _test: "@include add-gutter('.25')";
    @include add-gutter('.25');
    _test: "@include sgs-change('direction', 'rtl')";
    @include sgs-change('direction', 'rtl');

    @include show-settings;

    _test: "@include sgs-reset('grids', 'gutters')";
    @include sgs-reset('grids', 'gutters');
    @include show-settings;
  }
}