@import "../shared";

$add-grid: 3, 5 at 500px, 1 3 5 at 700px;

.add-grid-basic {
  @include show-settings;
  @each $grid in $add-grid {
    @include add-grid($grid);
    _grid: '@include add-grid(#{$grid})';
  }
  @include show-settings;
}

@include sgs-reset('grids');

$bkpt-1: 500px ('min-resolution' 1.5dppx);
$bkpt-2: 700px, 'no-query' '.no-mq';

$add-grid: 3, 5 at $bkpt-1, 1 3 5 at $bkpt-2;

.add-grid-breakpoint {
  @include show-settings;
  @each $grid in $add-grid {
    @include add-grid($grid);
    _grid: '@include add-grid(#{$grid})';
  }
  @include show-settings;
}